Subroutines
***********

.. currentmodule:: ModernGL

.. autoclass:: Subroutine
	:members: name, index

.. autoclass:: SubroutineMap

	.. automethod:: __getitem__(key) -> Subroutine

.. toctree::
	:maxdepth: 4
